##-*- Mode: CPerl -*-
use Test::More tests=>6;

use_ok('PDL::CCS::IO::Common');
use_ok('PDL::CCS::IO::FastRaw');
use_ok('PDL::CCS::IO::FITS');
use_ok('PDL::CCS::IO::MatrixMarket');
use_ok('PDL::CCS::IO::LDAC');
use_ok('PDL::CCS::IO::PETSc');
